package ru.ibs.tests;

import org.junit.*;
import org.openqa.selenium.By;
import ru.ibs.framework.managers.DriverManager;
import ru.ibs.framework.utils.AllureUtils;
import ru.ibs.framework.utils.MyAllureListener;

public class ApplineBusinessTripTest extends BaseTests {

    private LoginPage loginPage;
    private DashboardPage dashboardPage;
    private BusinessTripPage businessTripPage;

    @Rule
    public MyAllureListener allureListener = new MyAllureListener();

    @Before
    public void setUp() {
        // Получаем драйвер из DriverManager (инициализирован в BaseTests)
        loginPage = new LoginPage(DriverManager.getDriverManager().getDriver());

        // Открываем страницу логина
        DriverManager.getDriverManager().getDriver().get("http://training.appline.ru/user/login");
    }

    @Test
    public void applineLoginScenario() {
        AllureUtils.attachScreenshot();
        dashboardPage = loginPage.login("Irina Filippova", "testing");
        Assert.assertTrue("Dashboard not loaded", dashboardPage.isDashboardLoaded());

        businessTripPage = dashboardPage.goToBusinessTrip();
        Assert.assertTrue("Trips page not loaded", businessTripPage.isTripsPageLoaded());

        businessTripPage.openCreateTripForm();

        businessTripPage.selectDepartment("Отдел внутренней разработки");
        businessTripPage.selectOrganization("Edge");
        businessTripPage.setTicketsCheckbox(true);
        businessTripPage.fillCity("Дмитров");

        AllureUtils.attachScreenshot();

        businessTripPage.fillDate(
                By.xpath("//input[@placeholder='Укажите дату' and contains(@id, 'departureDatePlan')]"),
                "01.01.2025"
        );

        businessTripPage.fillDate(
                By.xpath("//input[@placeholder='Укажите дату' and contains(@id, 'returnDatePlan')]"),
                "10.01.2025"
        );

        AllureUtils.attachScreenshot();

        businessTripPage.saveAndClose();

        Assert.assertTrue("Expected validation error not shown",
                businessTripPage.isErrorDisplayed("Список командируемых сотрудников не может быть пустым"));
    }

}
